#!/system/bin/sh
# Please don't hardcode /magisk/modname/... ; instead, please use $MODDIR/...
# This will make your scripts compatible even if Magisk change its mount point in the future
MODDIR=${0%/*}

# This script will be executed in post-fs-data mode
# More info in the main Magisk thread

# Magisk Module variable
NotificationPolicySysFile=/data/system/notification_policy.xml

# Check notification policy exists
if [ -f $NotificationPolicySysFile ];
then
    # Find the offset of word zen
    ZenOffsetLines=$(strings -t d $NotificationPolicySysFile | grep -w zen)
    for ZenOffsetLine in $ZenOffsetLines
    do
        ZenOffset=`echo "$ZenOffsetLine" | xargs | cut -d " " -f1`
        # Find the first occurence close to file beginning 
        if [ -z "${ZenOffset##*[0-9]*}" ]; 
        then
            break
        fi
    done

    # Find the offset of word areChannelsBypassingDnd
    BypassingDndOffsetLines=$(strings -t d $NotificationPolicySysFile | grep areChannelsBypassingDnd)
    for BypassingDndOffsetLine in $BypassingDndOffsetLines
    do
        BypassingDndOffset=`echo "$BypassingDndOffsetLine" | xargs | cut -d " " -f1`
        # Find the first occurence close to file beginning 
        if [ -z "${BypassingDndOffset##*[0-9]*}" ]; 
        then
            break
        fi
    done

    # Check that zen and areChannelsBypassingDnd offset exist
    if [ $ZenOffset -a $BypassingDndOffset ]; 
    then
        # Find messages and convos string and print its offset
        MessagesOffsetLines=$(strings -t d $NotificationPolicySysFile | grep -w messages)
        ConvosOffsetLines=$(strings -t d $NotificationPolicySysFile | grep -E -w '(convos|convoso)' )
        # For each one of the messages offsets
        for MessagesOffsetLine in $MessagesOffsetLines
        do
            # Parses the offset number
            MessagesOffset=`echo "$MessagesOffsetLine" | xargs | cut -d " " -f1`
            
            # Check that offset is a number and is greater or equal to 5 and between zen offset and areChannelsBypassingDnd offset
            if [ -z "${MessagesOffset##*[0-9]*}" -a "$MessagesOffset" -ge "5" -a "$MessagesOffset" -ge "$ZenOffset" -a "$MessagesOffset" -le "$BypassingDndOffset" ]; 
            then
                # Go 5 bytes before offset to search for boolean false binary sequence
                SearchBegin=$(($MessagesOffset - 5))
            
                # Extract the 13 bytes corresponding to messages=false binary sequence
                SearchString=$(dd if=$NotificationPolicySysFile bs=1 skip=$SearchBegin count=13 conv=notrunc status=none | xxd -p)
                    
                # Check that the extracted sequence is messages=false
                if [ "$SearchString" = "dfffff00086d65737361676573" ]; 
                then
                    # Replace the first byte of the sequence to change it to messages=true
                    printf '\xcf' | dd of=$NotificationPolicySysFile bs=1 seek=$SearchBegin count=1 conv=notrunc status=none
                fi
            fi
        done
        # For each one of the convos offsets
        for ConvosOffsetLine in $ConvosOffsetLines
        do
            # Parses the offset number
            ConvosOffset=`echo "$ConvosOffsetLine" | xargs | cut -d " " -f1`
            
            # Check that offset is a number and is greater or equal to 5 and between zen offset and areChannelsBypassingDnd offset
            if [ -z "${ConvosOffset##*[0-9]*}" -a "$ConvosOffset" -ge "5" -a "$ConvosOffset" -ge "$ZenOffset" -a "$ConvosOffset" -le "$BypassingDndOffset" ]; 
            then
                # Go 5 bytes before offset to search for boolean false binary sequence
                SearchBegin=$(($ConvosOffset - 5))
            
                # Extract the 11 bytes corresponding to convos=false binary sequence
                SearchString=$(dd if=$NotificationPolicySysFile bs=1 skip=$SearchBegin count=11 conv=notrunc status=none | xxd -p)
                    
                # Check that the extracted sequence is convos=false
                if [ "$SearchString" = "dfffff0006636f6e766f73" ]; 
                then
                    # Replace the first byte of the sequence to change it to convos=true
                    printf '\xcf' | dd of=$NotificationPolicySysFile bs=1 seek=$SearchBegin count=1 conv=notrunc status=none
                fi
            fi
        done
    fi
fi

exit 0
